/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.actions.name;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.operations.IUndoableOperation;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.ITaxEditorConstants;
import eu.etaxonomy.taxeditor.TaxEditorPlugin;
import eu.etaxonomy.taxeditor.controller.EditorController;
import eu.etaxonomy.taxeditor.controller.GlobalController;
import eu.etaxonomy.taxeditor.operations.name.ChangeConceptRelationOperation;
import eu.etaxonomy.taxeditor.operations.name.CreateConceptRelationOperation;

/**
 * @author n.hoffmann
 * @created 03.02.2009
 * @version 1.0
 */
public class ChangeConceptRelationAction extends Action {

	private static final Logger logger = Logger
			.getLogger(ChangeConceptRelationAction.class);

	private static String text = "Change concept relation";
	private static ImageDescriptor image = TaxEditorPlugin.getDefault()
			.getImageRegistry().getDescriptor(ITaxEditorConstants.CONCEPT_ICON);

	private Taxon relatedTaxon;

	private Taxon taxon;

	private TaxonRelationshipType taxonRelationshipType;

	private ChangeConceptRelationAction(){
		super(text, image);
	}
	
	public ChangeConceptRelationAction(Taxon taxon, Taxon relatedTaxon,
			TaxonRelationshipType taxonRelationshipType) {
		this();
		this.setText(taxonRelationshipType.getLabel());
		this.taxon = taxon;
		this.relatedTaxon = relatedTaxon;
		this.taxonRelationshipType = taxonRelationshipType;
	}
	
	public void run() {
		IUndoableOperation operation = new ChangeConceptRelationOperation(
				"Create concept relation '" + taxonRelationshipType.getLabel() + "'", 
				EditorController.getUndoContext(taxon), taxon, relatedTaxon, taxonRelationshipType);
		
		GlobalController.executeOperation(operation);
	}
}
