/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.actions.name;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.operations.IUndoableOperation;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;

import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.ITaxEditorConstants;
import eu.etaxonomy.taxeditor.TaxEditorPlugin;
import eu.etaxonomy.taxeditor.controller.EditorController;
import eu.etaxonomy.taxeditor.controller.GlobalController;
import eu.etaxonomy.taxeditor.operations.name.RemoveSynonymOperation;

/**
 * @author n.hoffmann
 * @created 02.02.2009
 * @version 1.0
 */
public class RemoveSynonymAction extends Action {

	private static final Logger logger = Logger
			.getLogger(RemoveSynonymAction.class);
	
	private static final String text = "Remove synonym from taxon"; //$NON-NLS-1$
	private static final ImageDescriptor image = TaxEditorPlugin.getDefault()
			.getImageDescriptor(ITaxEditorConstants.ACTIVE_DELETE_ICON);

	private Synonym synonym;

	private Taxon taxon;
	
	private RemoveSynonymAction() {
		super(text, image);
	}
	
	public RemoveSynonymAction(Taxon taxon, Synonym synonym) {
		this();
		this.taxon = taxon;
		this.synonym = synonym;
	}
	
	public void run() {
		IUndoableOperation operation = new RemoveSynonymOperation
				(this.getText(), EditorController.getUndoContext(taxon), taxon, synonym);
		
		GlobalController.executeOperation(operation);				
	}
}
