/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.name;

import org.apache.log4j.Logger;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.forms.IManagedForm;
import org.eclipse.ui.views.properties.IPropertySource;

import eu.etaxonomy.cdm.model.name.Rank;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.actions.name.CreateAutonymAction;
import eu.etaxonomy.taxeditor.actions.name.CreateConceptRelationAction;
import eu.etaxonomy.taxeditor.actions.name.CreateHeterotypicSynonymAction;
import eu.etaxonomy.taxeditor.actions.name.CreateSynonymInGroupAction;
import eu.etaxonomy.taxeditor.actions.name.CreateMisappliedNameAction;
import eu.etaxonomy.taxeditor.actions.name.CreateTaxonomicallyIncludedTaxonAction;
import eu.etaxonomy.taxeditor.actions.ui.ChangeTaxonToSynonymAction;
import eu.etaxonomy.taxeditor.actions.ui.MoveTaxonDialogAction;
import eu.etaxonomy.taxeditor.editor.ContextMenu;
import eu.etaxonomy.taxeditor.editor.MenuConstants;
import eu.etaxonomy.taxeditor.model.CdmSessionDataRepository;
import eu.etaxonomy.taxeditor.propertysheet.name.TaxonBasePropertySource;

/**
 * @author p.ciardelli
 * @created 13.01.2009
 * @version 1.0
 */
public class AcceptedNameComposite extends NameComposite {
	@SuppressWarnings("unused")
	private static final Logger logger = Logger
			.getLogger(AcceptedNameComposite.class);
	
	public AcceptedNameComposite(Composite groupComposite, IManagedForm form,
			Taxon taxon) {
		super(groupComposite, form, NameComposite.ACCEPTED_TAXON, taxon);
	
		setIsDraggable(false);
		setIcon(ACCEPTED_ICON);
		setFont(getViewerFont());
		setIndent(ACCEPTED_INDENT);

		createMenu();
		
		initTextViewer(taxon);
	}

	private void createMenu() {
		ContextMenu contextMenu = createContextMenu();

		contextMenu.setMenuManager(MenuConstants.EDITOR_TAXON_MENU());
		
//		contextMenu.addAction(new CreateHeterotypicSynonymAction());
//		contextMenu.addAction(new CreateSynonymInGroupAction());
//		contextMenu.addSeparator();			
//		contextMenu.addAction(new CreateMisappliedNameAction());
//		
//		MenuManager subMenu = new MenuManager("Create concept relation");
//		for (TaxonRelationshipType type : 
//				CdmSessionDataRepository.getDefault().getConceptRelationshipTypes()) {
//			subMenu.add(new CreateConceptRelationAction(type));
//		}
//		contextMenu.addSubmenu(subMenu);
//		contextMenu.addSeparator();	
//		contextMenu.addAction(new MoveTaxonDialogAction());
//		contextMenu.addAction(new ChangeTaxonToSynonymAction());
//		contextMenu.addSeparator();
//		// TODO is it correct that onlx taxa with rank species may have autonyms?
//	//	if(getTaxon().getName().getRank().equals(Rank.SPECIES())){
//			contextMenu.addAction(new CreateAutonymAction());
//	//	}
//		contextMenu.addAction(new CreateTaxonomicallyIncludedTaxonAction());
		
		textViewer.getTextWidget().setMenu(contextMenu.getMenu());
	}

	
	public IPropertySource getPropertySource() {
		return new TaxonBasePropertySource(taxon, "Accepted Name");
	}
	
	@Override
	protected Font getViewerFont() {
		return ACCEPTED_FONT;
	}

	@Override
	protected TaxonNameBase getName() {
		return taxon.getName();
	}
	
	public Object getData () {
		return getTaxon();
	}
}