/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.name;

import org.apache.log4j.Logger;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.forms.IManagedForm;
import org.eclipse.ui.views.properties.IPropertySource;

import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationship;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.actions.name.ChangeConceptRelationAction;
import eu.etaxonomy.taxeditor.actions.name.RemoveConceptAction;
import eu.etaxonomy.taxeditor.editor.ContextMenu;
import eu.etaxonomy.taxeditor.model.CdmSessionDataRepository;
import eu.etaxonomy.taxeditor.propertysheet.name.TaxonBasePropertySource;

/**
 * @author p.ciardelli
 * @created 26.01.2009
 * @version 1.0
 */
public class ConceptComposite extends NameComposite {
	private static final Logger logger = Logger
			.getLogger(ConceptComposite.class);
	
	private Taxon relatedTaxon;
	private TaxonRelationshipType relationshipType;
	
	/**
	 * 
	 */
	private boolean acceptedTaxonIsFromTaxon;
		
	private ConceptComposite(Composite parent, IManagedForm form,
			Taxon taxon, Taxon relatedTaxon, TaxonRelationshipType relationshipType, 
			boolean acceptedTaxonIsFromTaxon) {
		super(parent, form, NameComposite.CONCEPTRELATION, relatedTaxon);
		
		this.taxon = taxon;
		this.relatedTaxon = relatedTaxon;
		this.relationshipType = relationshipType;
		this.acceptedTaxonIsFromTaxon = acceptedTaxonIsFromTaxon;
		
		setIsDraggable(true);
		setIcon(CONCEPT_ICON);
		setFont(getViewerFont());
		setIndent(CONCEPT_INDENT);

		createMenu();
		
		showRelationshipType();
		showSec();
				
		initTextViewer(relatedTaxon);
	}
	
	private void showRelationshipType() {
		setNonEditableInfo(relationshipType.getLabel());
	}

	private void showSec() {
		if (relatedTaxon == null) {
			return;
		}
		
		if (relatedTaxon.getSec() == null) {
			setNonEditableInfo("sec. ???");
		} else {
			setNonEditableInfo("sec. " + relatedTaxon.getSec().getTitleCache());
		}
	}

	public static ConceptComposite getNewInstance(Composite parent, IManagedForm form,
			Taxon taxon, TaxonRelationship relationship){

		TaxonRelationshipType relationshipType = relationship.getType();
		
		if (relationship.getToTaxon().equals(taxon)) {
			return new ConceptComposite (parent, form, taxon, 
					relationship.getFromTaxon(), relationshipType, false);
		} else {
			return new ConceptComposite (parent, form, taxon, 
					relationship.getToTaxon(), relationshipType, true);
		} 
	}

	private void createMenu() {
		ContextMenu contextMenu = createContextMenu();
		
		// Remove misapplied name from taxon
		contextMenu.addAction(new RemoveConceptAction(taxon, relatedTaxon, relationshipType));
		MenuManager subMenu = new MenuManager("Change relation type");
		for (TaxonRelationshipType type : CdmSessionDataRepository.getDefault().getConceptRelationshipTypes()) {
			subMenu.add(new ChangeConceptRelationAction(taxon, relatedTaxon, type));
		}
		contextMenu.addSubmenu(subMenu);
	}


	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.GroupedComposite#getViewerFont()
	 */
	@Override
	protected Font getViewerFont() {
		return CONCEPT_FONT;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.IHasPropertySource#getPropertySource()
	 */
	
	public IPropertySource getPropertySource() {
		return new TaxonBasePropertySource(relatedTaxon, "Concept Name");
	}

	public Taxon getRelatedTaxon() {
		return relatedTaxon;
	}
	
	protected TaxonNameBase getName() {
		return relatedTaxon.getName();
	}
	
	protected void calculateErrors() {
		super.calculateErrors();
		
		textViewer.setShowSecError(relatedTaxon);
	}
	
	public Object getData () {
		return getRelatedTaxon();
	}
}






