/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.operations.name;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.operations.AbstractEditorOperation;

/**
 * @author n.hoffmann
 * @created 03.02.2009
 * @version 1.0
 */
public class ChangeConceptRelationOperation extends AbstractEditorOperation {


	private static final Logger logger = Logger
			.getLogger(ChangeConceptRelationOperation.class);
	private Taxon relatedTaxon;
	private TaxonRelationshipType oldRelationshipType;
	private TaxonRelationshipType newRelationshipType;

	public ChangeConceptRelationOperation(String label,
			IUndoContext undoContext, Taxon taxon, Taxon relatedTaxon, TaxonRelationshipType type) {
		super(label, undoContext, taxon);
		this.relatedTaxon = relatedTaxon;
//		this.oldRelationshipType = relatedTaxon.get
		this.newRelationshipType = type;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		// Remove relatedTaxon and old relationship
		// FIXME since taxon relationships come in a set, which relationships are we going to delete here?
//		taxon.removeTaxon(relatedTaxon, oldRelationshipType);
		// Add new relationship
		// TODO add microcitation for misapplied name to property sheet
		relatedTaxon.addTaxonRelation(taxon, newRelationshipType, null, null);	
		
		return redrawOpenEditor();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		return execute(monitor, info);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		// see FIXME in execute()
		logger.warn("Not implemented yet. See developer documentation for details");
		return null;
	}
}
