/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */
package eu.etaxonomy.taxeditor.propertysheet.type;

import java.util.Collection;

import org.apache.log4j.Logger;

import eu.etaxonomy.cdm.model.name.NameRelationship;
import eu.etaxonomy.cdm.model.name.NameRelationshipType;
import eu.etaxonomy.cdm.model.name.SpecimenTypeDesignation;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.taxeditor.controller.GlobalController;
import eu.etaxonomy.taxeditor.propertysheet.CollectionPropertySource;

public class TypeCollectionPropertySource extends CollectionPropertySource {
	private static final Logger logger = Logger
			.getLogger(TypeCollectionPropertySource.class);
	
	private TaxonNameBase name;

	public TypeCollectionPropertySource(TaxonNameBase name, Collection collection) {
		super(collection);
		this.name = name;
	}
	
	@Override
	protected String getItemDisplayName(Object item) {
		String str = "";
		
		if (item instanceof SpecimenTypeDesignation) {
			
			SpecimenTypeDesignation typeDesignation = (SpecimenTypeDesignation) item;
			
			if (typeDesignation.getTypeStatus() != null) {
				str = typeDesignation.getTypeStatus().getLabel();
			}
		}
		return str;
	}

	@Override
	public Object getPropertyValue(Object id) {
		String str = "";
		
		if (id instanceof SpecimenTypeDesignation) {
			
			SpecimenTypeDesignation typeDesignation = (SpecimenTypeDesignation) id;
						
			if (typeDesignation.getTypeSpecimen() != null) {
				str = typeDesignation.getTypeSpecimen().getTitleCache();
			} else {
				str = "UNDEFINED";
			}
		}
		return str;
	}

	@Override
	public void setPropertyValue(Object id, Object value) {
		// Fields not editable in property sheet view
	}

	@Override
	public String toString() {
		// "Name Relations" header has no value
		return "";
	}
}