/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.type.wizard;

import org.apache.log4j.Logger;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CCombo;
import org.eclipse.swt.events.KeyAdapter;
import org.eclipse.swt.events.KeyEvent;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.model.common.TermVocabulary;
import eu.etaxonomy.cdm.model.name.SpecimenTypeDesignation;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.name.TypeDesignationStatus;
import eu.etaxonomy.cdm.model.occurrence.Specimen;
import eu.etaxonomy.taxeditor.model.CdmSessionDataRepository;

/**
 * @author p.ciardelli
 * @created 13.02.2009
 * @version 1.0
 */
public class ChooseTypeDesignationWizardPage extends WizardPage {
	private static Logger logger = Logger
			.getLogger(ChooseTypeDesignationWizardPage.class);

	private TaxonNameBase name;	
	private SpecimenTypeDesignation typeDesignation;
	
	private CCombo statusCombo;
	private Text txtDesignationType;

	private TypeDesignationStatus[] typeStatusArray;

	/**
	 * @param typeDesignation
	 */
	public ChooseTypeDesignationWizardPage(
			SpecimenTypeDesignation typeDesignation, TaxonNameBase name) {
		super("");
				
		this.typeDesignation = typeDesignation;
		this.name = name;
		
		setTitle("Create or edit type designation");
		setDescription("Create or edit type designation for '" + name.getTitleCache() + "\".");
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	@Override
	public void createControl(Composite parent) {
		
		// Create composite for popup dialog	
		Composite container = new Composite(parent, SWT.NULL);
		final GridLayout gridLayout = new GridLayout();
		container.setLayout(gridLayout);
		setControl(container);

		// Create text
		final Label lblChooseStatus = new Label(container, SWT.NONE);
		lblChooseStatus.setText("Choose designation type status:");

		// Create designation type status dropdown 
		statusCombo = new CCombo(container, SWT.BORDER);
		statusCombo.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
		TermVocabulary<TypeDesignationStatus> typeStatusSet = CdmSessionDataRepository.getDefault().getTypeDesignationStatus();
		typeStatusArray = new TypeDesignationStatus[CdmSessionDataRepository.getDefault().getTypeDesignationStatus().size()];
		int i = 0;
		int selectedIndex = -1;
		for (TypeDesignationStatus typeStatus : 
				CdmSessionDataRepository.getDefault().getTypeDesignationStatus()) {
			String label = typeStatus.getLabel();
			typeStatusArray[i] = typeStatus;
			
			if (typeDesignation != null && typeDesignation.getTypeStatus() != null) {
				if (typeStatus.equals(typeDesignation.getTypeStatus())) {
					selectedIndex = i;
				}
			}
			
			i++;
			statusCombo.add(label);
		}
		
		// Set menu to type designation status if exists
		statusCombo.select(selectedIndex);

		statusCombo.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				updatePage();
			}
		});

		// Create text
		final Label lblEnterText = new Label(container, SWT.NONE);
		lblEnterText.setText("Enter designation type text:");
		
		txtDesignationType = new Text(container, SWT.BORDER);
		txtDesignationType.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
		txtDesignationType.addKeyListener(new KeyAdapter() {
			@Override
			public void keyReleased(KeyEvent e) {
				updatePage();
			}			
		});
		
		// Set text to specimen text if exists
		if (typeDesignation != null && typeDesignation.getTypeSpecimen() != null) {
			txtDesignationType.setText(typeDesignation.getTypeSpecimen().getTitleCache());
		}
	}

	@Override
	public boolean canFlipToNextPage() {
		return isPageComplete();
	}

	public boolean isPageComplete() {
		return (statusCombo.getSelectionIndex() > -1 
				&& txtDesignationType.getText().length() > 0);
	}
	
	private void updatePage() {
		
		getWizard().getContainer().updateButtons();
	}
	
    public void setPageComplete(boolean complete) {
        super.setPageComplete(complete);
        
        if (complete) {
        	
        	TypeDesignationStatus status = typeStatusArray[statusCombo.getSelectionIndex()];
        	
        	Specimen specimen;
        	if (typeDesignation == null || typeDesignation.getTypeSpecimen() == null) {
        		specimen = Specimen.NewInstance();
        		typeDesignation.setTypeSpecimen(specimen);
        	} else {
        		specimen = (Specimen) typeDesignation.getTypeSpecimen(); // Next version (or 3 or 4 version from now) - this or something like this will return specimen: 
        	}
        	specimen.setTitleCache(txtDesignationType.getText());
        	
        	if (typeDesignation == null) {
        		name.addSpecimenTypeDesignation(specimen, status, null, null, null, true, true);
        	} else {
        		typeDesignation.setTypeStatus(status);
        	}
        }
    }
}
