/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.type.wizard;

import org.apache.log4j.Logger;
import org.eclipse.core.databinding.beans.BeansObservables;
import org.eclipse.core.databinding.observable.list.WritableList;
import org.eclipse.core.databinding.observable.map.IObservableMap;
import org.eclipse.jface.databinding.viewers.ObservableListContentProvider;
import org.eclipse.jface.databinding.viewers.ObservableMapLabelProvider;
import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.window.Window;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableItem;

import eu.etaxonomy.cdm.model.name.SpecimenTypeDesignation;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.taxeditor.controller.GlobalController;
import eu.etaxonomy.taxeditor.model.CdmUtil;

/**
 * @author p.ciardelli
 * @created 11.02.2009
 * @version 1.0
 */
public class ListTypeWizardPage extends WizardPage {
	private static Logger logger = Logger.getLogger(ListTypeWizardPage.class);
	private TaxonNameBase name;

	/**
	 * @param name
	 */
	public ListTypeWizardPage(TaxonNameBase name, WritableList typeDesignationsList) {
		super("");
		this.name = name;
		
		this.typeDesignationsList = typeDesignationsList;

		setTitle("Type designations for \""
				+ CdmUtil.getDisplayName(name) + "\".");
		setDescription("Select a type designation and click \"Edit ...\" or \"Remove\", or click \"Add ...\" to create a new designation.");
	}
	
	private Table typeDesignationsTable;
	private WritableList typeDesignationsList = new WritableList();

	private Button btnRemove;
	private Button btnEdit;

	private SpecimenTypeDesignation typeDesignation;
	private TableViewer tableViewer;


	public void createControl(Composite parent) {
		Composite container = new Composite(parent, SWT.NULL);
		final GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 3;
		container.setLayout(gridLayout);

		setControl(container);

		btnEdit = new Button(container, SWT.NONE);
		btnEdit.setText("Edit ...");
		btnEdit.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				if (getSelectedTypeDesignation() != null) {	
					createTypeDesignationWizard(getSelectedTypeDesignation());
				}
			}
		});

		btnRemove = new Button(container, SWT.NONE);
		btnRemove.setText("Remove");
		btnRemove.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				if (getSelectedTypeDesignation() != null) {
					typeDesignationsList.remove(getSelectedTypeDesignation());
					setSelectedTypeDesignation(null);
				}
			}
		});

		setEnableTypeDesignationButtons(false);

		final Button btnAdd = new Button(container, SWT.NONE);
		final GridData gd_btnAdd = new GridData(SWT.RIGHT, SWT.CENTER, true,
				false);
		btnAdd.setLayoutData(gd_btnAdd);
		btnAdd.setText("Add ...");
		btnAdd.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				createTypeDesignationWizard(null);
			}
		});

		tableViewer = new TableViewer(container, SWT.BORDER | SWT.SINGLE);

		typeDesignationsTable = tableViewer.getTable();
		typeDesignationsTable.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true,
				true, 3, 1));
		typeDesignationsTable.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) { 
				setEnableTypeDesignationButtons(true);
				TableItem[] selectedItem = typeDesignationsTable.getSelection();
				if (e.item.getData() instanceof SpecimenTypeDesignation) {
					setSelectedTypeDesignation((SpecimenTypeDesignation) e.item.getData());
				}
			}
		});

		ObservableListContentProvider providerList = new ObservableListContentProvider();
		tableViewer.setContentProvider(providerList);

		IObservableMap[] providerMaps = BeansObservables.observeMaps(
				providerList.getKnownElements(), SpecimenTypeDesignation.class,
				new String[] { "typeSpecimen", "typeStatus" });
		tableViewer.setLabelProvider(new ObservableMapLabelProvider(
				providerMaps) {
			public String getColumnText(Object element, int columnIndex) {
				if (element instanceof SpecimenTypeDesignation) {
					SpecimenTypeDesignation typeDesignation = (SpecimenTypeDesignation) element;
					return getTypeDesignationString(typeDesignation);
				}
				return "";
			}

			public Image getColumnImage(Object element, int columnIndex) {
				if (element instanceof SpecimenTypeDesignation) {
					SpecimenTypeDesignation typeDesignation = (SpecimenTypeDesignation) element;
					return getTypeDesignationImage(typeDesignation);
				}
				return null;
			}
		});
		
		tableViewer.setInput(typeDesignationsList);
		tableViewer.addDoubleClickListener(new IDoubleClickListener() {
			public void doubleClick(DoubleClickEvent event) {
				if (((StructuredSelection) event.getSelection())
						.getFirstElement() instanceof SpecimenTypeDesignation) {
					SpecimenTypeDesignation typeDesignation = (SpecimenTypeDesignation) 
							((StructuredSelection) event.getSelection()).getFirstElement();
					createTypeDesignationWizard(typeDesignation);
				}
			}
		});
	}

	private void setSelectedTypeDesignation(SpecimenTypeDesignation typeDesignation) {
		this.typeDesignation = typeDesignation;
	}

	private SpecimenTypeDesignation getSelectedTypeDesignation() {
		return typeDesignation;
	}
	
	private void createTypeDesignationWizard(SpecimenTypeDesignation typeDesignation) {
		Wizard wizard = new TypeDesignationWizard(typeDesignation, name, typeDesignationsList);
		
		WizardDialog dialog = new WizardDialog(GlobalController.getShell(), wizard);
		dialog.create();
		dialog.open();
//		if (dialog.open() == Window.OK) ...
	}

	protected void setEnableTypeDesignationButtons(boolean enabled) {
		btnRemove.setEnabled(enabled);
		btnEdit.setEnabled(enabled);
	}

	private Image getTypeDesignationImage(SpecimenTypeDesignation typeDesignation) {
		return null;
	}

	private String getTypeDesignationString(SpecimenTypeDesignation typeDesignation) {
		String str = "";
		if (typeDesignation.getTypeSpecimen() != null) {
			str += typeDesignation.getTypeSpecimen().getTitleCache();
		} else {
			str += "UNDEFINED";
		}
		if (typeDesignation.getTypeStatus() != null) {
			str += " [" + typeDesignation.getTypeStatus().getLabel() + "]";
		}
		
		return str;
	}
}
