/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.type.wizard;

import org.apache.log4j.Logger;
import org.eclipse.core.databinding.observable.list.WritableList;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.jface.wizard.WizardPage;

import eu.etaxonomy.cdm.model.name.SpecimenTypeDesignation;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;

/**
 * @author p.ciardelli
 * @created 13.02.2009
 * @version 1.0
 */
public class TypeDesignationWizard extends Wizard {
	
	private static Logger logger = Logger
			.getLogger(TypeDesignationWizard.class);
	
	private SpecimenTypeDesignation typeDesignation;
	private TaxonNameBase name;
	private WritableList typeDesignationsList;

	public class TemporarySpecimenTypeDesignation extends
			SpecimenTypeDesignation {
		TemporarySpecimenTypeDesignation() {
			super();
		}
	}
	
	private WizardPage chooseNamePage;

	/**
	 * @param typeDesignation
	 * @param typeDesignationsList 
	 */
	public TypeDesignationWizard(SpecimenTypeDesignation typeDesignation, TaxonNameBase name, WritableList typeDesignationsList) {

		this.name = name;
		if (typeDesignation == null) {
			createEmptyTypeDesignation();
		} else {
			this.typeDesignation = typeDesignation;
		}
		this.typeDesignationsList = typeDesignationsList;
	}

	/**
	 * 
	 */
	private void createEmptyTypeDesignation() {
		typeDesignation = new TemporarySpecimenTypeDesignation(); 
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#addPages()
	 */
	public void addPages() {
		chooseNamePage = new ChooseTypeDesignationWizardPage(typeDesignation, name);
    	addPage(chooseNamePage);
    }
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	@Override
	public boolean performFinish() {
		
		chooseNamePage.setPageComplete(true);
		
		// Remove then re-add in case any name editing has taken place
		typeDesignationsList.remove(typeDesignation);
		typeDesignationsList.add(typeDesignation);
		
		return true;
	}
}
