/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.type.wizard;

import org.apache.log4j.Logger;
import org.eclipse.core.databinding.observable.list.WritableList;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.Wizard;

import eu.etaxonomy.cdm.model.name.SpecimenTypeDesignation;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.occurrence.Specimen;

/**
 * @author p.ciardelli
 * @created 11.02.2009
 * @version 1.0
 */
public class TypeListWizard extends Wizard {
	private static Logger logger = Logger.getLogger(TypeListWizard.class);

	private TaxonNameBase name;
	private WritableList typeDesignationsList;
	
	/**
	 * @param name
	 */
	public TypeListWizard(TaxonNameBase name) {
		super();
		
		this.name = name;
		this.typeDesignationsList = new WritableList();
		if (name != null) {
			this.typeDesignationsList.addAll(name.getSpecimenTypeDesignations());
		}
	}

	public void addPages(){
		IWizardPage chooseTypePage = new ListTypeWizardPage(name, typeDesignationsList);
    	addPage(chooseTypePage);
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	@Override
	public boolean performFinish() {
		
		if (name != null) {
			
			// Remove all designations
			for (Object typeDesignation : name.getSpecimenTypeDesignations()) {
				if (typeDesignation instanceof SpecimenTypeDesignation) {
					name.removeTypeDesignation((SpecimenTypeDesignation) typeDesignation);
				}
			}
			
			// Then re-add them from list
			for (Object typeDesignation : typeDesignationsList) {
				if (typeDesignation instanceof SpecimenTypeDesignation) {
					name.addSpecimenTypeDesignation(
						(Specimen) ((SpecimenTypeDesignation) typeDesignation).getTypeSpecimen(),
						((SpecimenTypeDesignation) typeDesignation).getTypeStatus(),
						((SpecimenTypeDesignation) typeDesignation).getCitation(),
						((SpecimenTypeDesignation) typeDesignation).getCitationMicroReference(),
						((SpecimenTypeDesignation) typeDesignation).getOriginalNameString(),
						((SpecimenTypeDesignation) typeDesignation).isNotDesignated(),
						false);
				}				
			}
		}
		return true;
	}
}
